// $TheSupernovaDuo: suwako,v 1.5.1 2023/4/15 23:9:28 yakumo_izuru Exp $
// Command line client for SimplyTranslate, a privacy friendly frontend to other translation engines
package main

import (
	"encoding/json"
	"flag"
	"fmt"
	"log"
	"net/http"
	"net/url"
	"os"

	"github.com/joho/godotenv"
	"marisa.chaotic.ninja/suwako"
)

var (
	engine string
	instance string
	input string
	source string
	target string
)
type Translate struct {
	Output string `json:"translated_text"`
}
func loadCfg() {
	flag.StringVar(&source, "f", "auto", "Set the language to translate from. This can be skipped as it will autodetect the language you're translating from")
	flag.StringVar(&input, "i", "", "Enter the text to be translated")
	flag.StringVar(&target, "t", "", "Set the language to translate to")

	flag.Usage = func() {
		fmt.Printf("usage: suwako -f [lang] -i [text] -t [lang]\nversion: %v\n", suwako.FullVersion())
	}

	home, err := os.UserHomeDir()
	sanityCheck(err)
	conf := home + "/.suwako/suwako.conf"
	err = godotenv.Load(conf)
	sanityCheck(err)

	engine = os.Getenv("SUWAKO_ENGINE")
	instance = os.Getenv("SUWAKO_INSTANCE")

	flag.Parse()
}
func check() {
	if len(input) == 0 || len(target) == 0 {
		log.Fatal("Either there is no input or there is no target language")
	}
}
func main() {
	loadCfg()
	check()
	
	var translate Translate
	var encInput = url.PathEscape(input)
	var apiEndpoint = "/api/translate"
	var queryURL = instance + apiEndpoint + "?engine=" + engine + "&from=" + source + "&to=" + target + "&text=" + encInput

	resp, err := http.Get(queryURL)
	sanityCheck(err)
	defer resp.Body.Close()
	_ = json.NewDecoder(resp.Body).Decode(&translate)
	sanityCheck(err)
	fmt.Printf("%v\n",translate.Output)
}
func sanityCheck(err error) {
	if err != nil {
		log.Fatal(err)
	}
}
